@@ -60,7 +60,7 @@ FP::Failure - failure values
  # request recorded backtrace to be shown
  is_equal $v->message(1),
           join("\n", "failure: 666 at lib/FP/Failure.pm line 54",
-                     "    (eval) at t/pod_snippets line 126",
+                     "    (eval) at t/pod_snippets line 132",
                      "  because:",
                      "  failure: 'not good'\n");
 
@@ -166,7 +166,7 @@ package FP::Failure::Failure {
          ],
         "maybe_trace", # [[caller(0)],...]
         ],
-        'FP::Show::Base::FP_Struct';
+        'FP::Struct::Show';
 
     use overload
         bool=> sub { undef },
@@ -260,7 +260,7 @@ sub fails ($;$) {
 
 package FP::Failure::Abstract::Message {
     use FP::Struct [],
-        'FP::Show::Base::FP_Struct';
+        'FP::Struct::Show';
     _END_
 }
 
